@@ -1,9 +1,11 @@
 from .feedback import Feedback
+from .formatters import CustomHelpFormatter
 from .progress_bar import ProgressBar
 from .reports import generate_settings_report
 from .table_logger import TableLogger
 
 __all__ = (
+    "CustomHelpFormatter",
     "Feedback",
     "ProgressBar",
     "TableLogger",
